function [ delays ] = EvalDelays(Solution, spice_model, edges, V_oh )
    %%% Solution: vector of parameters for the spice_model
    %%% spice_model: Function that takes parameters, and returns vectors of
    %%% results as time samples
    %%% edges is a struct array specifing input_change_time
    %%% returns delays, which has the delay for each edge in edges
    %%%
    %%% WARNING: Assumes Step change on inputs (does not assess)
    %%%
    %%% EXAMPLE:
    %%%edges = struct(...
    %%%'input_change_time', 1e-9,...
    %%%'time_signal','time',...
    %%%'output_signal', res.VOUT,...
    %%%'output_change_type', 'falling' );
    %%%%edges(2) = struct(...
    %%%'input_change_time', 10e-9,...
    %%%'time_signal','time',...
    %%%'output_signal', res.VOUT,...
    %%'output_change_type', 'rising' );
    global num_errors
    
    try
        res = spice_model(Solution); 
            %Will throw exception if doesn't converge and so produced no output
        delays = props(res, edges, V_oh);
    catch err
        %A variety of errors are caused when simulation fails
        %They are not a problem (directly).
        delays = Inf;
        num_errors=num_errors+1.0;
        fprintf('%i:%s\n',num_errors, err.message);
        %rethrow(err) 
    end
    
end

