function [delays] = props(...
                spice_results,...
                edges,...,
                V_oh)
    %%% Finds the propergation delays from 
    %%% spices is a vector of then results were recorded
    %%% it must incles a .TIME field
    %%% and a field o the name of the output signal
    %%% edges is a struct array specifing input_change_time
    %%% returns delays, which has the delay for each edge in edges
    %%% WARNING: Assumes Step change on inputs (does not assess)
    %%%
    %%% EXAMPLE:
    %%%edges = struct(...
    %%%'input_change_time', 1e-9,...
    %%%'time_signal','time',...
    %%%'output_signal', 'VOUT',...
    %%%'output_change_type', 'falling' );
    %%%%edges(2) = struct(...
    %%%'input_change_time', 10e-9,...
    %%%'time_signal','time',...
    %%%'output_signal', 'VOUT',...
    %%'output_change_type', 'rising' );
    %%delays = props(res.TIME, edges, 3)        
            
            
    delays = zeros(length(edges),1);
            

    for edge_no = (1:length(edges))
        this_edge = edges(edge_no);
        out_sig = [spice_results.(this_edge.output_signal)];
        time_sig = [spice_results.(this_edge.time_signal)];
        
        start_time = this_edge.input_change_time;
        start_idx=find(time_sig>=start_time,1,'first');
   
        
        if strcmpi(this_edge.output_change_type, 'falling')
            if(out_sig(start_idx)<=0.9*V_oh)
               error('output signal was not high at start of fall');
            end
            
            end_idx=start_idx + ...
                       find(out_sig(start_idx:end)<0.5*V_oh,1,'first');
            
        else
            assert(strcmpi(this_edge.output_change_type, 'rising'));
            if(out_sig(start_idx)>=0.1*V_oh)
               error('output signal was not low at start of rise');
            end
            
            end_idx=start_idx + ...
                       find(out_sig(start_idx:end)>0.5*V_oh,1,'first');
        end
        
        end_time = time_sig(end_idx);
        delays(edge_no)= end_time-start_time;
    end
        